betty.ancestry.event_type module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.event_type module

Provide Betty’s ancestry event types.

final class betty.ancestry.event_type.Adoption

  Bases: `DuringLifeEventType`, `_EventTypeShorthandBase`

  Someone was adopted.

final class betty.ancestry.event_type.Baptism

  Bases: `DuringLifeEventType`, `StartOfLifeEventType`, `_EventTypeShorthandBase`

  Someone was baptized.

final class betty.ancestry.event_type.Birth

  Bases: `CreatableDerivableEventType`, `StartOfLifeEventType`, `_EventTypeShorthandBase`

  Someone was born.

  classmethod comes_before() → set[type[EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

final class betty.ancestry.event_type.Burial

  Bases: `FinalDispositionEventType`, `_EventTypeShorthandBase`

  Someone was buried.

final class betty.ancestry.event_type.Conference

  Bases: `_EventTypeShorthandBase`, `DuringLifeEventType`

  A conference between people took place.

final class betty.ancestry.event_type.Confirmation

  Bases: `_EventTypeShorthandBase`, `DuringLifeEventType`

  Someone’s confirmation took place.

final class betty.ancestry.event_type.Correspondence

  Bases: `_EventTypeShorthandBase`

  People corresponded with each other.

class betty.ancestry.event_type.CreatableDerivableEventType

  Bases: `DerivableEventType`

  Any event type of which the deriver API may create new instances.

  classmethod may_create(person: Person, lifetime_threshold: int) → bool

    Whether a new event of this type may be created for the given person.

final class betty.ancestry.event_type.Cremation

  Bases: `FinalDispositionEventType`, `_EventTypeShorthandBase`

  Someone was cremated.

final class betty.ancestry.event_type.Death

  Bases: `CreatableDerivableEventType`, `EndOfLifeEventType`, `_EventTypeShorthandBase`

  Someone died.

  classmethod comes_after() → set[type[EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

  classmethod may_create(person: Person, lifetime_threshold: int) → bool

    Whether a new event of this type may be created for the given person.

class betty.ancestry.event_type.DerivableEventType

  Bases: `_EventTypeShorthandBase`

  Any event that that may be updated by the deriver API.

final class betty.ancestry.event_type.Divorce

  Bases: `DuringLifeEventType`, `_EventTypeShorthandBase`

  People were divorced.

  classmethod comes_after() → set[type[EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

final class betty.ancestry.event_type.DivorceAnnouncement

  Bases: `DuringLifeEventType`, `_EventTypeShorthandBase`

  People’s divorce was announced.

  classmethod comes_after() → set[type[EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

  classmethod comes_before() → set[type[EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

class betty.ancestry.event_type.DuringLifeEventType

  Bases: `EventType`

  Any event that only ever takes place during someone’s life, e.g. after their birth and before their death.

  classmethod comes_after() → set[type[EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

  classmethod comes_before() → set[type[EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

betty.ancestry.event_type.EVENT_TYPE_REPOSITORY: PluginRepository[EventType] = <betty.plugin.entry_point.EntryPointPluginRepository object>

  The event type plugin repository.

  Read more about Event type plugins.

final class betty.ancestry.event_type.Emigration

  Bases: `_EventTypeShorthandBase`, `DuringLifeEventType`

  Someone emigrated from a place.

class betty.ancestry.event_type.EndOfLifeEventType

  Bases: `EventType`

  An event that indicates the end of someone’s life.

  This includes someone’s actual death, but also other types of events that take place close to someone’s death and as such are indicators that that person died around the time of the end-of-life event.

final class betty.ancestry.event_type.Engagement

  Bases: `DuringLifeEventType`, `_EventTypeShorthandBase`

  People got engaged with the intent to marry.

  classmethod comes_before() → set[type[EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

class betty.ancestry.event_type.EventType

  Bases: `Plugin`

  Define an `betty.ancestry.Event` type.

  Read more about Event type plugins.

  To test your own subclasses, use `betty.test_utils.ancestry.event_type.EventTypeTestBase`.

  classmethod comes_after() → set[type[EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

  classmethod comes_before() → set[type[EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

class betty.ancestry.event_type.FinalDispositionEventType

  Bases: `PostDeathEventType`, `DerivableEventType`, `EndOfLifeEventType`

  Someone’s final disposition took place.

final class betty.ancestry.event_type.Funeral

  Bases: `FinalDispositionEventType`, `_EventTypeShorthandBase`

  Someone’s funeral took place.

final class betty.ancestry.event_type.Immigration

  Bases: `DuringLifeEventType`, `_EventTypeShorthandBase`

  Someone immigrated to a place.

final class betty.ancestry.event_type.Marriage

  Bases: `DuringLifeEventType`, `_EventTypeShorthandBase`

  People were married.

final class betty.ancestry.event_type.MarriageAnnouncement

  Bases: `DuringLifeEventType`, `_EventTypeShorthandBase`

  People’s marriage was announced.

  classmethod comes_before() → set[type[EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

final class betty.ancestry.event_type.Missing

  Bases: `_EventTypeShorthandBase`, `DuringLifeEventType`

  Someone went missing.

final class betty.ancestry.event_type.Occupation

  Bases: `_EventTypeShorthandBase`, `DuringLifeEventType`

  Someone’s occupation, e.g. their main recurring activity.

  This may include employment, education, stay at home parent, etc.

class betty.ancestry.event_type.PostDeathEventType

  Bases: `EventType`

  An event that only ever happens after someone’s death.

  classmethod comes_after() → set[type[EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

class betty.ancestry.event_type.PreBirthEventType

  Bases: `EventType`

  Any event that only ever takes place before someone’s birth.

  classmethod comes_before() → set[type[EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

final class betty.ancestry.event_type.Residence

  Bases: `DuringLifeEventType`, `_EventTypeShorthandBase`

  Someone resided/lived in a place.

final class betty.ancestry.event_type.Retirement

  Bases: `_EventTypeShorthandBase`, `DuringLifeEventType`

  Someone retired.

class betty.ancestry.event_type.StartOfLifeEventType

  Bases: `EventType`

  An event that indicates the start of someone’s life.

  This includes someone’s actual birth, but also other types of events that take place close to someone’s birth and as such are indicators that that person was born around the time of the start-of-life event.

final class betty.ancestry.event_type.UnknownEventType

  Bases: `_EventTypeShorthandBase`

  Describe an event for which no more specific type is known.

final class betty.ancestry.event_type.Will

  Bases: `PostDeathEventType`, `_EventTypeShorthandBase`

  Someone’s will and testament came into effect.